@@ -3,10 +3,12 @@ from .embryo_generator_model import *
 from .embryo_segmentor import *
 from .tests import test ## tests/test.py/<class test()>
 
-__version__ = "0.2.2"
+__version__ = "0.3.0"
 
 ## folder names below
-__all__ = ["lineage_populaton_model",
-            "embryo_generator_model",
-            "embryo_segmentor",
-            "tests"]
\ No newline at end of file
+__all__ = [
+    "lineage_populaton_model",
+    "embryo_generator_model",
+    "embryo_segmentor",
+    "tests"
+]
\ No newline at end of file
