@@ -10,8 +10,7 @@ import torchvision.models as models
 import os
 import cv2
 import wget
-from tqdm import tqdm
-from tqdm.notebook import tqdm as tqdm_notebook
+from tqdm import tqdm, tqdm_notebook
 from PIL import Image
 import joblib
 import numpy as np
@@ -28,6 +27,13 @@ GAN to generate images of embryos
 
 class Generator(nn.Module):
     def __init__(self, ngf, nz, nc):
+        """GAN generator to generate synthetic images of embryos
+
+        Args:
+            ngf (int): size of feature maps in generator
+            nz (int): size of latent space noise (latent vector)
+            nc (int): number of color channels of the output image
+        """
         super().__init__()
         self.main = nn.Sequential(
             # input is Z, going into a convolution
@@ -65,20 +71,18 @@ class Generator(nn.Module):
 
 
 class embryo_generator_model():   
-    def __init__(self, mode = "cpu"):
-
-        """
-        ngf = size of feature maps in generator
-        nz = size of latent space noise (latent vector)
-        nc = number of color channels of the output image
+    def __init__(self, device = "cpu"):
+        """Generate synthetic single or multiple images of embryos.
         Do not tweak these unless you're changing the Generator() with a new model with a different architecture. 
-    
-        """
 
+        Args:
+            device (str, optional): set to "cuda", runs operations on gpu and set to "cpu", runs operations on cpu. Defaults to "cpu".
+        """
+        self.device = device
         self.ngf = 128 ## generated image size 
         self.nz = 128
         self.nc = 1
-        self.generator= Generator(self.ngf, self.nz, self.nc)
+        self.generator = Generator(self.ngf, self.nz, self.nc)
         self.model_url = "https://raw.githubusercontent.com/DevoLearn/devolearn/master/devolearn/embryo_generator_model/embryo_generator.pth"
         self.model_name = "embryo_generator.pth"
         self.model_dir = os.path.dirname(__file__)
@@ -87,15 +91,16 @@ class embryo_generator_model():
 
         try:
             # print("model already downloaded, loading model...")
-            self.generator.load_state_dict(torch.load(self.model_dir + "/" + self.model_name, map_location= "cpu"))
+            self.generator.load_state_dict(torch.load(self.model_dir + "/" + self.model_name, map_location= self.device))
         except:
             print("model not found, downloading from: ", self.model_url)
             if os.path.isdir(self.model_dir) == False:
                 os.mkdir(self.model_dir)
             filename = wget.download(self.model_url, out= self.model_dir)
             # print(filename)
-            self.generator.load_state_dict(torch.load(self.model_dir + "/" + self.model_name, map_location= "cpu"))
-
+            self.generator.load_state_dict(torch.load(self.model_dir + "/" + self.model_name, map_location= self.device))
+        
+        self.generator.to(self.device)
 
 
         
@@ -103,22 +108,20 @@ class embryo_generator_model():
 
 
     def generate(self, image_size = (700,500)):
-
-        """
+        """Generate one synthetic image of embryo.
+        The native size of the GAN's output is 256*256, and then it resizes the generated image to the desired size. 
         reference{
             https://github.com/DevoLearn/devolearn#generating-synthetic-images-of-embryos-with-a-pre-trained-gan
         }
-        inputs{
-            image_size <tuple> = (width,height of the generated image)
-        }
-        outputs{
-            1 channel image as an <np.array> 
-        }
-        The native size of the GAN's output is 256*256, and then it resizes the 
-        generated image to the desired size. 
+
+        Args:
+            image_size (tuple, optional): size of generated image,(width,height). Defaults to (700,500).
+
+        Returns:
+            np.array : 1 channel image 
         """
         with torch.no_grad():
-            noise = torch.randn([1,128,1,1])
+            noise = torch.randn([1,128,1,1]).to(self.device)
             im = self.generator(noise)[0][0].cpu().detach().numpy()
         im = cv2.resize(im, image_size)
         im = 255 - cv2.convertScaleAbs(im, alpha=(255.0))   ## temporary fix against inverted images 
@@ -127,21 +130,15 @@ class embryo_generator_model():
 
 
     def generate_n_images(self, n = 3, foldername = "generated_images", image_size = (700,500), notebook_mode = False):
-        """
+        """This is an extension of the generator.generate() function for generating multiple images at once and saving them into a folder. 
         reference{
             https://github.com/DevoLearn/devolearn#generating-synthetic-images-of-embryos-with-a-pre-trained-gan
         }
-        inputs{
-            n <int> = number of images to generate
-            foldername <str> = name of the folder where the images whould be saved. 
-            The function automatically generates a folder if it doesn't exist 
-            notebook_mode <bool> = toogle between script(False) and notebook(True), for better user interface
-        }
-        outputs{
-            None
-        }
-        
-        This is an extension of the generator.generate() function for generating multiple images at once and saving them into a folder. 
+        Args:
+            n (int, optional): number of images to generate. Defaults to 3.
+            foldername (str, optional): name of the folder where the images whould be savedThe function automatically generates a folder if it doesn't exist. Defaults to "generated_images".
+            image_size (tuple, optional): size of generated image,(width,height). Defaults to (700,500).
+            notebook_mode (bool, optional): toogle between script(False) and notebook(True), for better user interface. Defaults to False.
         """
 
         if os.path.isdir(foldername) == False:
